==> peperit_2.1.01_estable.zip: themes/peperit/html_files/componentes/carrusel_productos/sliderProductos.php <==
<?php

/* 
 * To change this license header, choose License Headers in Project Properties.
 * To change this template file, choose Tools | Templates
 * and open the template in the editor.
 */

?>
<div class="slider-productos">
        <?php
//Vamos a cargar el escaparate de novedades
        $elemento_destacado = new Escaparate(NULL, 0, "home2", 1);
//limitado a 1
        
        $elemento_destacado->carga_articulos(0, 12);
?>
            <h4 class="title_block title_font"> 
                <a href="<?= $elemento_destacado->url; ?>" title="<?= $elemento_destacado->nombre_seo; ?>"> 
                    
                    <?= mb_strtolower($elemento_destacado->nombre_seo); ?>	
                </a>
            </h4>
<?php
        $extraParams = $elemento_destacado->lista_articulos;
        $opciones = new OpcionesWidget(
                array(
            'numSlides' => count($extraParams),
            'extraParams' => $extraParams,
            //'ficheroSlide' => 'slideProducto',
			'ficheroSlide' => 'mini_ficha_semaforo',
            'hasIndicator' => 'false',
            'dataType' => 'multi',
			'playOnLoad' => false
                )
        );
        new Widget($_WH->GW("carrousel", "carrousel"), $opciones);
        ?>
        <script>
			document.addEventListener('WSLE', function(event) {
				$('.carousel[data-type="multi"] .item').each(function () {
					var next = $(this).next();
					if (!next.length) {
						next = $(this).siblings(':first');
					}
					next.children(':first-child').clone().appendTo($(this));

					for (var i = 0; i < 4; i++) {
						next = next.next();
						if (!next.length) {
							next = $(this).siblings(':first');
						}

						next.children(':first-child').clone().appendTo($(this));
					}
				});
				//Vamos a poner las imágenes a manubrio
				$('.carousel[data-type="multi"] .item').each(function () {
					$(this).find('img').each(function(){
						//Esto lo hacemos por el lazy load
						if ( ($(this).attr('src') == null) || ($(this).attr('src').indexOf("loading.gif") >= 0) ){	//Si es nulo o la imagen es la de carga
							//if ($(this).attr('data-src') != null){
								$(this).attr('src', $(this).attr('data-src'));
							//}
						}
					});
				});
			});
        </script>
    </div>

==> peperit_2.1.02_estable.zip: themes/peperit/html_files/componentes/carrusel_productos/sliderProductos.php <==
<?php

/* 
 * To change this license header, choose License Headers in Project Properties.
 * To change this template file, choose Tools | Templates
 * and open the template in the editor.
 */

?>
<div class="slider-productos">
        <?php
//Vamos a cargar el escaparate de novedades
        $elemento_destacado = new Escaparate(NULL, 0, "home2", 1);
//limitado a 1
        
        $elemento_destacado->carga_articulos(0, 12);
?>
            <h4 class="title_block title_font"> 
                <a href="<?= $elemento_destacado->url; ?>" title="<?= $elemento_destacado->nombre_seo; ?>"> 
                    
                    <?= mb_strtolower($elemento_destacado->nombre_seo); ?>	
                </a>
            </h4>
<?php
        $extraParams = $elemento_destacado->lista_articulos;
        $opciones = new OpcionesWidget(
                array(
            'numSlides' => count($extraParams),
            'extraParams' => $extraParams,
            //'ficheroSlide' => 'slideProducto',
			'ficheroSlide' => 'mini_ficha_semaforo',
            'hasIndicator' => 'false',
            'dataType' => 'multi',
			'playOnLoad' => false
                )
        );
        new Widget($_WH->GW("carrousel", "carrousel"), $opciones);
        ?>
        <script>
			document.addEventListener('WSLE', function(event) {
				$('.carousel[data-type="multi"] .item').each(function () {
					var next = $(this).next();
					if (!next.length) {
						next = $(this).siblings(':first');
					}
					next.children(':first-child').clone().appendTo($(this));

					for (var i = 0; i < 4; i++) {
						next = next.next();
						if (!next.length) {
							next = $(this).siblings(':first');
						}

						next.children(':first-child').clone().appendTo($(this));
					}
					//Pedro 22/Septiembre/2020 ==> Esto lo tenemos que hacer por cada slider para no programar más eventos de la cuenta
					$(this).find('img').each(function(){
						//Esto lo hacemos por el lazy load
						if ( ($(this).attr('src') == '' ) || ($(this).attr('src') == null) || ($(this).attr('src').indexOf("loading.gif") >= 0) ){	//Si es nulo o la imagen es la de carga
							//if ($(this).attr('data-src') != null){
								$(this).attr('src', $(this).attr('data-src'));
							//}
						}
					});
				});
				/*
				//Vamos a poner las imágenes a manubrio
				$('.carousel[data-type="multi"] .item').each(function () {
					$(this).find('img').each(function(){
						//Esto lo hacemos por el lazy load
						if ( ($(this).attr('src') == null) || ($(this).attr('src').indexOf("loading.gif") >= 0) ){	//Si es nulo o la imagen es la de carga
							//if ($(this).attr('data-src') != null){
								$(this).attr('src', $(this).attr('data-src'));
							//}
						}
					});
				});
				*/
			});
        </script>
    </div>
